@@ -1,5 +1,6 @@
 import logging
 import traceback
+from argparse import OPTIONAL
 from threading import Thread
 from typing import Optional
 
@@ -9,7 +10,7 @@ from django.template.exceptions import TemplateDoesNotExist
 from django.template.loader import render_to_string
 from django.utils.translation import gettext as _
 
-from .utils import import_class
+from .utils import import_attribute
 
 logger = logging.getLogger("notifier")
 
@@ -21,14 +22,14 @@ class Emailer:
         receivers: list,
         template: Optional[str],
         context: dict,
-        smtp_account: str='default',
+        email_gateway: str='default',
         final_message: str = None,
         files: list = None,
         **kwargs,
     ):
-        from magic_notifier.settings import NOTIFIER_SMTP
-        self.email_settings:dict = NOTIFIER_SMTP[smtp_account]
-        self.email_client = import_class(self.email_settings["CLIENT"])
+        from magic_notifier.settings import NOTIFIER_EMAIL
+        self.email_settings:dict = NOTIFIER_EMAIL[email_gateway]
+        self.email_client = import_attribute(self.email_settings["CLIENT"])
 
         self.connection = self.email_client.get_connection(self.email_settings)
         self.subject: str = subject
@@ -37,7 +38,7 @@ class Emailer:
         self.context: dict = context if context else {}
         self.final_message = final_message
         self.threaded: bool = kwargs.get("threaded", False)
-        self.files: list = files
+        self.files: Optional[list] = files
 
     def send(self):
         if self.threaded:
