@@ -12,8 +12,8 @@ class CGSmsClient(BaseSmsClient):
 
     @classmethod
     def send(cls, number: str, text: str):
-        sub_account = settings.NOTIFIER["CGS"]["SUB_ACCOUNT"]
-        sub_account_pass = settings.NOTIFIER["CGS"]["SUB_ACCOUNT_PASSWORD"]
+        sub_account = settings.NOTIFIER["SMS"]["GATEWAYS"]["CGS"]["SUB_ACCOUNT"]
+        sub_account_pass = settings.NOTIFIER["SMS"]["GATEWAYS"]["CGS"]["SUB_ACCOUNT_PASSWORD"]
         params = {
             "sub_account": sub_account,
             "sub_account_pass": sub_account_pass,
@@ -23,6 +23,3 @@ class CGSmsClient(BaseSmsClient):
         }
         res = requests.get("http://cheapglobalsms.com/api_v1", params=params)
         return res
-
-if __name__ == "__main__":
-    CGSmsClient.send("0000000000", "Cava ma tigresse")
