@@ -12,9 +12,9 @@ class TwilioClient(BaseSmsClient):
 
     @classmethod
     def send(cls, number: str, text: str):
-        account = settings.NOTIFIER["TWILIO"]["ACCOUNT"]
-        token = settings.NOTIFIER["TWILIO"]["TOKEN"]
-        from_number = settings.NOTIFIER["TWILIO"]["FROM_NUMBER"]
+        account = settings.NOTIFIER["SMS"]["GATEWAYS"]["TWILIO"]["ACCOUNT"]
+        token = settings.NOTIFIER["SMS"]["GATEWAYS"]["TWILIO"]["TOKEN"]
+        from_number = settings.NOTIFIER["SMS"]["GATEWAYS"]["TWILIO"]["FROM_NUMBER"]
         client = Client(account, token)
         res = client.messages.create(from_=from_number, to=number, body=text)
         return res
